==> upd-2.0-32.tgz: home/hadmin/html/diags/ping.php <==
<?PHP
/* $Id: ping.php,v 1.5 2001/04/23 11:18:04 bzizou Exp $

Make a ping to test the connection

This script is part of the SLIS Project initiated by the CARMI-Internet
(Acadmie de Grenoble - France 38).
Ce script fait partie du projet SLIS dmarr par le CARMI-Internet
(Acadmie de Grenoble - France 38).

This script have been writen by Bruno Bzeznik - copyright (C) 2001
Ce script  t crit par Bruno Bzeznik - copyright (C) - 2001

SLIS : Serveur de communications Linux pour l'Internet Scolaire.
Copyright (C) 1998-2001 Bruno Bzeznik

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details. You should have received a copy of the GNU General Public License
along with this program (For example ./COPYING);
if not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.

Please send all comments and bug reports by electronic mail
to: <slis@ac-grenoble.fr>
Envoyez vos suggestions et reports de bugs par e-mail  <slis@ac-grenoble.fr>
*/

// loading libs and init
require("../inc/html.inc.php");
require("../inc/lib.inc.php");
print startHTML("Ping");
$text ="<BR>\n";

// Print the ifconfig
$text .= "<CENTER>Interfaces</CENTER><BR>\n";
exec("/sbin/ifconfig -a",$if);
$text .= "<TT><PRE>\n";
for ($i=0;$i<count($if);$i++) {
  $text .= $if[$i] ."\n";
}
$text .= "</PRE></TT><P>\n";

// Print the routes table and search for the default gateway
$text .= "<CENTER>Routes</CENTER><BR>\n";
exec("/bin/netstat -rn",$routes);
$text .= "<TT><PRE>\n";
for ($i=0;$i<count($routes);$i++) {
  $text .= $routes[$i] ."\n";
  // Get the default gateway
  $route=split(" +",$routes[$i]);
  if ($route[0] == "0.0.0.0" && $route[2] == "0.0.0.0") { $gateway=$route[1]; }
}
$text .= "</PRE></TT>\n";


// Ping the gateway
$text .="<BR><CENTER>Pinging default gateway $gateway...<BR>\n";

$ping="ping -c 1 $gateway | awk '/packet/ {print $7}'";
$line=exec($ping,$test,$rc);

// Prepare the report
if ($line == "0%"){ $status=1;} 
else { $status=0;}   
if ($status == 1) { 
  $text .= "<B>Gateway OK</B>\n";
}
else {
  $text .= "<FONT COLOR=FF0000><B>FAILED!</B></FONT>\n";
}

$text .= "<P>\n";

// Search for the variable containing the host to ping.
// if $PING_HOST is already defined, it will be used if valid.

if (!preg_match("/^.+\..+\..+/",$PING_HOST)) {
  $setup_file="";
  $PING_HOST="";
  if (file_exists("/home/hadmin/setup.data")) {
    $setup_file="/home/hadmin/setup.data";
  }
  elseif (file_exists("/root/slis/setup.data")) {
    $setup_file="/root/slis/setup.data";
  }
  else {
    $text .= "<B><FONT COLOR=FF0000>FILE setup.data not found!</FONT></B><P>";
  }
  if ($setup_file != "") {
    $data=file("$setup_file");
    $grep=preg_grep("/^\s*PING_HOST.*=/",$data);
    $eval="$". $grep[0] .";";
    if ($eval != "\$;") { eval ($eval);}
  }
}

if (!preg_match("/^.+\..+\..+/",$PING_HOST)) { $PING_HOST=$SMART_HOST_IP; }

if (!preg_match("/^.+\..+\..+/",$PING_HOST)) {
  $text .= "<B><FONT COLOR=FF0000>Variable PING_HOST not set!</FONT></B><P>";
}  

// Ping the external host
$ping="ping -c 1 $PING_HOST | awk '/packet/ {print $7}'";
$line=exec($ping,$test,$rc); // 1rst time to open the link if not opened
$line=exec($ping,$test,$rc); // 2nd time to be sure

// Prepare the report
$text .= "Pinging $PING_HOST...<BR>\n";
if ($line == "0%"){ $status=1;} 
else { $status=0;}   
if ($status == 1) { 
  $text .= "<B>Connection OK</B>\n";
}
else {
  $text .= "<FONT COLOR=FF0000><B>FAILED!</B></FONT>\n";
}


$text .= "<BR><BR></FONT>\n";
$val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$text,$border,$lang_adv_Ping,$titre_color); 
$val = center($val);
$val = saut(2)."$val";
print "$val\n";        


// The end
print endHTML();

?>

==> upd-2.0-37.tgz: home/hadmin/html/diags/ping.php <==
<?PHP
/* $Id: ping.php,v 1.6 2001/06/12 17:28:52 bzizou Exp $

Make a ping to test the connection

This script is part of the SLIS Project initiated by the CARMI-Internet
(Acadmie de Grenoble - France 38).
Ce script fait partie du projet SLIS dmarr par le CARMI-Internet
(Acadmie de Grenoble - France 38).

This script have been writen by Bruno Bzeznik - copyright (C) 2001
Ce script  t crit par Bruno Bzeznik - copyright (C) - 2001

SLIS : Serveur de communications Linux pour l'Internet Scolaire.
Copyright (C) 1998-2001 Bruno Bzeznik

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your
option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details. You should have received a copy of the GNU General Public License
along with this program (For example ./COPYING);
if not, write to the Free Software Foundation, Inc., 675 Mass Ave,
Cambridge, MA 02139, USA.

Please send all comments and bug reports by electronic mail
to: <slis@ac-grenoble.fr>
Envoyez vos suggestions et reports de bugs par e-mail  <slis@ac-grenoble.fr>
*/

// loading libs and init
require("../inc/html.inc.php");
require("../inc/lib.inc.php");
print startHTML("Ping");
$text ="<BR>\n";

// Print the ifconfig
$text .= "<CENTER>Interfaces</CENTER><BR>\n";
exec("/sbin/ifconfig -a",$if);
$text .= "<TT><PRE>\n";
for ($i=0;$i<count($if);$i++) {
  $text .= $if[$i] ."\n";
}
$text .= "</PRE></TT><P>\n";

// Print the routes table and search for the default gateway
$text .= "<CENTER>Routes</CENTER><BR>\n";
exec("/bin/netstat -rn",$routes);
$text .= "<TT><PRE>\n";
for ($i=0;$i<count($routes);$i++) {
  $text .= $routes[$i] ."\n";
  // Get the default gateway
  $route=split(" +",$routes[$i]);
  if ($route[0] == "0.0.0.0" && $route[2] == "0.0.0.0") { $gateway=$route[1]; }
}
$text .= "</PRE></TT>\n";


// Ping the gateway
$text .="<BR><CENTER>Pinging default gateway $gateway...<BR>\n";

$ping="ping -c 1 $gateway | awk '/packet/ {print $7}'";
$line=exec($ping,$test,$rc);

// Prepare the report
if ($line == "0%"){ $status=1;} 
else { $status=0;}   
if ($status == 1) { 
  $text .= "<B>Gateway OK</B>\n";
}
else {
  $text .= "<FONT COLOR=FF0000><B>FAILED!</B></FONT>\n";
}

$text .= "<P>\n";

// Search for the variable containing the host to ping.
// if $PING_HOST is already defined, it will be used if valid.

if (!isip($PING_HOST)) {
  $setup_file="";
  $PING_HOST="";
  if (file_exists("/home/hadmin/setup.data")) {
    $setup_file="/home/hadmin/setup.data";
  }
  elseif (file_exists("/root/slis/setup.data")) {
    $setup_file="/root/slis/setup.data";
  }
  else {
    $text .= "<B><FONT COLOR=FF0000>FILE setup.data not found!</FONT></B><P>";
  }
  if ($setup_file != "") {
    $data=file("$setup_file");
    $grep=preg_grep("/^\s*PING_HOST.*=/",$data);
    $eval="$". $grep[0] .";";
    if ($eval != "\$;") { eval ($eval);}
  }
}

if (!isip($PING_HOST)) { $PING_HOST=$SMART_HOST_IP; }

if (!isip($PING_HOST)) {
  $text .= "<B><FONT COLOR=FF0000>Variable PING_HOST not set!</FONT></B><P>";
}  

// Ping the external host
$ping="ping -c 1 $PING_HOST | awk '/packet/ {print $7}'";
$line=exec($ping,$test,$rc); // 1rst time to open the link if not opened
$line=exec($ping,$test,$rc); // 2nd time to be sure

// Prepare the report
$text .= "Pinging $PING_HOST...<BR>\n";
if ($line == "0%"){ $status=1;} 
else { $status=0;}   
if ($status == 1) { 
  $text .= "<B>Connection OK</B>\n";
}
else {
  $text .= "<FONT COLOR=FF0000><B>FAILED!</B></FONT>\n";
}


$text .= "<BR><BR></FONT>\n";
$val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$text,$border,$lang_adv_Ping,$titre_color); 
$val = center($val);
$val = saut(2)."$val";
print "$val\n";        


// The end
print endHTML();

?>
